@@ -285,7 +285,7 @@ class Bridge:
         self._master_socket.send(message)
         serialized_object = self._master_socket.receive()
         if new_socket:
-            socket = DataSocket(self._context, serialized_object["port"], zmq.REQ, ip_address=self.ip_address)
+            socket = DataSocket(self._context, serialized_object["port"], zmq.REQ, ip_address=self._ip_address)
         else:
             socket = self._master_socket
         return self._class_factory.create(
@@ -298,7 +298,7 @@ class Bridge:
         :param port:
         :return:
         """
-        return DataSocket(self._context, port, zmq.PUSH, debug=self._debug, ip_address=self.ip_address)
+        return DataSocket(self._context, port, zmq.PUSH, debug=self._debug, ip_address=self._ip_address)
 
     def _connect_pull(self, port):
         """
@@ -306,7 +306,7 @@ class Bridge:
         :param port:
         :return:
         """
-        return DataSocket(self._context, port, zmq.PULL, debug=self._debug, ip_address=self.ip_address)
+        return DataSocket(self._context, port, zmq.PULL, debug=self._debug, ip_address=self._ip_address)
 
     def get_magellan(self):
         """
